EvolutionCache

Struct EvolutionCache 

pub struct EvolutionCache { /* private fields */ }
Local gene cache with Thompson Sampling selection.

Example

use prismer_sdk::evolution_cache::EvolutionCache;
use prismer_sdk::types::SignalTag;

let mut cache = EvolutionCache::new();
// cache.load_snapshot(&snapshot);
// let result = cache.select_gene(&[SignalTag { signal_type: "error:timeout".into(), .. }]);

Implementations

Source

impl EvolutionCache

pub fn new() -> Self

Create a new empty evolution cache.

pub fn gene_count(&self) -> usize

Number of genes in the cache.

pub fn cursor(&self) -> u64

Current sync cursor.

pub fn load_snapshot(&mut self, snapshot: &Value)

Load from a full sync snapshot, replacing all existing data.

pub fn apply_delta(&mut self, delta: &Value)

Apply an incremental sync delta.

pub fn load_delta(&mut self, delta: &Value)

Alias for apply_delta (API parity).

pub fn select_gene(&self, signals: &[SignalTag]) -> GeneSelectionResult

Select the best gene for the given signals using Thompson Sampling. Pure CPU, <1ms.